# pydantic orm

[![pypi](https://img.shields.io/pypi/v/pydantic-orm?color=blue&style=plastic)](https://pypi.python.org/pypi/pydantic-orm)
[![versions](https://img.shields.io/pypi/pyversions/pydantic-orm)](https://pypi.org/pypi/pyversions/pydantic-orm)

Asynchronous database ORM using Pydantic.

## Installation

Install using `pip install -U pydantic-orm` or `poetry add pydantic-orm`
